@@ -1,7 +1,6 @@
 """ Contains some shared types for properties """
-from typing import (
-    BinaryIO, Generic, MutableMapping, Optional, TextIO, Tuple, TypeVar, Union,
-)
+from http import HTTPStatus
+from typing import BinaryIO, Generic, MutableMapping, Optional, Tuple, TypeVar
 
 import attr
 
@@ -13,19 +12,19 @@ class Unset:
 
 UNSET: Unset = Unset()
 
-FileJsonType = Tuple[Optional[str], Union[BinaryIO, TextIO], Optional[str]]
+FileJsonType = Tuple[Optional[str], BinaryIO, Optional[str]]
 
 
 @attr.s(auto_attribs=True)
 class File:
-    """ Contains information for file uploads """
+    """Contains information for file uploads"""
 
-    payload: Union[BinaryIO, TextIO]
+    payload: BinaryIO
     file_name: Optional[str] = None
     mime_type: Optional[str] = None
 
     def to_tuple(self) -> FileJsonType:
-        """ Return a tuple representation that httpx will accept for multipart/form-data """
+        """Return a tuple representation that httpx will accept for multipart/form-data"""
         return self.file_name, self.payload, self.mime_type
 
 
@@ -34,9 +33,9 @@ T = TypeVar("T")
 
 @attr.s(auto_attribs=True)
 class Response(Generic[T]):
-    """ A response from an endpoint """
+    """A response from an endpoint"""
 
-    status_code: int
+    status_code: HTTPStatus
     content: bytes
     headers: MutableMapping[str, str]
     parsed: Optional[T]
